## Product details

At Freshpet®, we believe pets deserve real, nourishing meals made from fresh, wholesome ingredients-just like the food we enjoy. Fresh from the fridge our Tender Chicken Recipe Slice & Serve Roll is crafted with premium ingredients to nourish your dog. Featuring US farm-raised chicken, this recipe is gently steam-cooked to preserve essential nutrients. Enriched with vitamin-packed peas and carrots and high-fiber brown rice, this recipe provides key minerals and energy to promote healthy digestion and support eye health, contributing to your dog’s overall well-being. Conveniently packaged in a slice-and-serve roll, this is the next best thing to a homemade meal that is healthy for your dog. Pets, People, and the Planet are central to everything we do at Freshpet®. Our mission is to bring fresh, real food to pets, helping them live their longest, happiest, and healthiest lives. We use simple, healthy ingredients, gently steaming each meal to retain its natural goodness and provide the essential nutrients dogs and cats need to lead their happiest, most tail-wagging lives.
Freshpet Fresh Dog Food, Tender Chicken Recipe, Slice & Serve Roll, 1 lb.
Natural US Farm Raised Chicken & Veggies You Can See
Gently Steam Cooked to Retain Essential Nutrients
Proven to Support Healthy Digestion
No Meat Meals or By-Product Meals
Vitamin and Antioxidant Rich Vegetables
No Preservatives or Fillers
Complete & Balanced for Small, Medium & Large Adult Dogs
Keep Refrigerated, Use within 7 days of opening
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Meat type
Chicken
Pet food condition
Fresh
Pet food form
Pate
Shelf life
135 days
More details
## Indications

Animal Health Concern
Allergy Relief Appetite Stimulation Coat Care Less Smelly Waste Skin Care Waste Reduction
Directions

## Instructions
When switching foods, gradually increase the new food and decrease the previous food to help make a smooth transition. Visit your veterinarian regularly to maintain your pet's health. Always provide fresh water. Freshpet® Select is ready to serve, simply cut using the serving marks. No heating required.
Feeding Instructions
Keep refrigerated.Depending on the age, activity level and condition of your dog, the feeding guidelines will need to be adjusted.Visit your veterinarian regularly to maintain your pet?s health.Always provide fresh water.
Fabric Care Instructions
N/A
Ingredients

## Ingredients
Chicken, Chicken Liver, Chicken Broth, Carrots, Peas, Eggs, Brown Rice, Rice Bran, Carrageenan, Natural Flavors, Salt, Potassium Chloride, Minerals (Zinc Proteinate, Iron Proteinate, Copper Proteinate, Manganese Proteinate, Sodium Selenite, Calcium Iodate), Vitamins (Choline Chloride, Vitamin E Supplement, Niacin, Calcium Pantothenate, Biotin, Thiamine Mononitrate, Riboflavin, Vitamin B12 Supplement, Vitamin D3 Supplement, Pyridoxine Hydrochloride, Folic Acid), Celery Powder

Active Ingredient Name
Chicken, Carrots, Chicken Broth, Peas, Egg, Chicken Liver, Brown Rice, Rice Bran, Carrageenan, Natural Flavors, Potassium Chloride, Celery Powder, Minerals (Zinc Proteinate, Iron Proteinate, Copper Proteinate, Manganese Proteinate, Sodium Selenite, Calcium Iodate), Salt, Vitamins (Choline Chloride, Vitamin E Supplement, Riboflavin, Biotin, Calcium Pantothenate, Niacin, Thiamine Mononitrate, Vitamin B12 Supplement, Pyridoxine Hydrochloride, Folic Acid), Spinach.
